pub struct get;
The http responder for a GET, query parameters and response are formatted as per the Webfinger spec.

The returned value’s links array contains two links, both have the Actor’s id as the href and "self" as the rel, with the type fields set to CT_ACTIVITY_JSON and CT_ACTIVITY_JSON_SHORT. Both versions of the link are provided for wider client compatibility.